tui

package
v0.0.0-...-df769fd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Package tui provides an interactive terminal UI for browsing and editing the Frisco shopping cart using the Bubble Tea framework.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunCart

func RunCart(s *session.Session, uid string) error

RunCart starts the interactive cart TUI (Bubble Tea: model / update / view).

func RunConfigEditor

func RunConfigEditor(cfg *config.Config) (config.Config, bool, error)

RunConfigEditor opens an interactive TUI for editing CLI config and returns the resulting config, a changed flag, and any validation error.

Types

This section is empty.

Jump to